@@ -19,15 +19,16 @@
 #'
 #' @example inst/examples/fastDoCall_ex.R
 #' @export
-fastDoCall <- function(what, args, quote = FALSE, envir = parent.frame()){
-  if (quote)
+fastDoCall <- function(what, args, quote = FALSE, envir = parent.frame()) {
+  if (quote) {
     args <- lapply(args, enquote)
+  }
 
   if (is.null(names(args)) ||
-        is.data.frame(args)){
+    is.data.frame(args)) {
     argn <- args
     args <- list()
-  }else{
+  } else {
     # Add all the named arguments
     argn <- lapply(names(args)[names(args) != ""], as.name)
     names(argn) <- names(args)[names(args) != ""]
@@ -36,25 +37,26 @@ fastDoCall <- function(what, args, quote = FALSE, envir = parent.frame()){
     args <- args[names(args) != ""]
   }
 
-  if ("character" %in% class(what)){
-    if(is.character(what)){
+  if ("character" %in% class(what)) {
+    if (is.character(what)) {
       fn <- strsplit(what, "[:]{2,3}")[[1]]
-      what <- if(length(fn)==1) {
-        get(fn[[1]], envir=envir, mode="function")
+      what <- if (length(fn) == 1) {
+        get(fn[[1]], envir = envir, mode = "function")
       } else {
-        get(fn[[2]], envir=asNamespace(fn[[1]]), mode="function")
+        get(fn[[2]], envir = asNamespace(fn[[1]]), mode = "function")
       }
     }
     call <- as.call(c(list(what), argn))
-  }else if ("function" %in% class(what)){
+  } else if ("function" %in% class(what)) {
     f_name <- deparse(substitute(what))
     call <- as.call(c(list(as.name(f_name)), argn))
     args[[f_name]] <- what
-  }else if ("name" %in% class(what)){
+  } else if ("name" %in% class(what)) {
     call <- as.call(c(list(what, argn)))
   }
 
   eval(call,
-       envir = args,
-       enclos = envir)
+    envir = args,
+    enclos = envir
+  )
 }
\ No newline at end of file
